@@ -6,7 +6,7 @@ use Dancer::Plugin::DBIC;
 use Dancer::Plugin::Auth::Extensible;
 
 use NetAddr::IP::Lite ':lower';
-use Net::MAC ();
+use NetAddr::MAC ();
 
 use App::Netdisco::Web::Plugin;
 use App::Netdisco::Util::Web 'sql_match';
@@ -20,9 +20,10 @@ ajax '/ajax/content/search/node' => require_login sub {
     content_type('text/html');
 
     my $agenot = param('age_invert') || '0';
-    my ( $start, $end ) = param('daterange') =~ /(\d+-\d+-\d+)/gmx;
+    my ( $start, $end ) = param('daterange') =~ m/(\d+-\d+-\d+)/gmx;
 
-    my $mac = Net::MAC->new(mac => $node, 'die' => 0, verbose => 0);
+    my $mac = NetAddr::MAC->new(mac => $node);
+    undef $mac if (defined $mac and $node =~ m/:{2}[a-f0-9]*$/i); # temp fix
     my @active = (param('archived') ? () : (-bool => 'active'));
 
     my @times = ();
@@ -48,7 +49,7 @@ ajax '/ajax/content/search/node' => require_login sub {
 
     my @where_mac =
       ($using_wildcards ? \['me.mac::text ILIKE ?', $likeval]
-                        : ($mac->get_error ? \'0=1' : ('me.mac' => $mac->as_IEEE)) );
+                        : ((!defined $mac or $mac->errstr) ? \'0=1' : ('me.mac' => $mac->as_ieee)) );
 
     my $sightings = schema('netdisco')->resultset('Node')
       ->search({-and => [@where_mac, @active, @times]}, {
